==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/ClusterControl/src/com/clustercontrol/bean/MonitorBlockConstant.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.bean;

import com.clustercontrol.util.Messages;

/**
 * ƻñ饹
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class MonitorBlockConstant {
    /** Ρ(ƻñ̤μ) */
    public static final int TYPE_NODE = 0;

    /** (ƻñ̤μ) */
    public static final int TYPE_SCOPE = 1;
    
    /** פȥΡ(ƻñ̤μ) */
    public static final int TYPE_ALL = 2;

    /** Ρ(ƻñ̤μ) */
    public static final String STRING_NODE = Messages.getString("node");

    /** (ƻñ̤μ) */
    public static final String STRING_SCOPE = Messages.getString("scope");

    /** פȥΡ(ƻñ̤μ) */
    public static final String STRING_ALL = Messages.getString("scope.node");

    /**
     * ̤ʸѴ
     * 
     * @param type
     * @return
     */
    public static String typeToString(int type) {
        if (type == TYPE_NODE) {
            return STRING_NODE;
        } else if (type == TYPE_SCOPE) {
            return STRING_SCOPE;
        } else if (type == TYPE_ALL) {
            return STRING_ALL;
        }
        return "";
    }

    /**
     * ʸ󤫤̤Ѵ
     * 
     * @param type
     * @return
     */
    public static int stringToType(String string) {
        if (string.equals(STRING_NODE)) {
            return TYPE_NODE;
        } else if (string.equals(STRING_SCOPE)) {
            return TYPE_SCOPE;
        } else if (string.equals(STRING_ALL)) {
            return TYPE_ALL;
        }
        return -1;
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/ClusterControl/src/com/clustercontrol/bean/MonitorBlockConstant.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.bean;

import com.clustercontrol.util.Messages;

/**
 * 監視単位定数クラス
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class MonitorBlockConstant {
    /** ノード(監視単位の種別) */
    public static final int TYPE_NODE = 0;

    /** スコープ(監視単位の種別) */
    public static final int TYPE_SCOPE = 1;
    
    /** スコープとノード(監視単位の種別) */
    public static final int TYPE_ALL = 2;

    /** ノード(監視単位の種別) */
    public static final String STRING_NODE = Messages.getString("node");

    /** スコープ(監視単位の種別) */
    public static final String STRING_SCOPE = Messages.getString("scope");

    /** スコープとノード(監視単位の種別) */
    public static final String STRING_ALL = Messages.getString("scope.node");

    /**
     * 種別から文字列に変換する
     * 
     * @param type
     * @return
     */
    public static String typeToString(int type) {
        if (type == TYPE_NODE) {
            return STRING_NODE;
        } else if (type == TYPE_SCOPE) {
            return STRING_SCOPE;
        } else if (type == TYPE_ALL) {
            return STRING_ALL;
        }
        return "";
    }

    /**
     * 文字列から種別に変換する
     * 
     * @param type
     * @return
     */
    public static int stringToType(String string) {
        if (string.equals(STRING_NODE)) {
            return TYPE_NODE;
        } else if (string.equals(STRING_SCOPE)) {
            return TYPE_SCOPE;
        } else if (string.equals(STRING_ALL)) {
            return TYPE_ALL;
        }
        return -1;
    }
}
